==> better-admin-ui-vue-0.0.2.tgz: package/es/components/index.js <==
import BigTable from './BigTable';
import Cascader from './Cascader';
import DateRange from './DateRange';
import DetailInfo from './DetailInfo';
import DictSelect from './DictSelect';
import DictText from './DictText';
import FileUpload from './FileUpload';
import Form from './Form';
import Image from './Image';
import Input from './Input';
import Loading from './Loading';
import MixedInput from './MixedInput';
import Modal from './Modal';
import MultipleSelect from './MultipleSelect';
import OssImage from './OssImage';
import PageHeader from './PageHeader';
import SearchBar from './SearchBar';
import SearchTable from './SearchTable';
import Select from './Select';
import SuggestSelect from './SuggestSelect';
import Table from './Table';
import TableOptions from './TableOptions';
import TextArea from './TextArea';
import { AbstractStep, BaseStepPage } from './Step';
import { FORM_ITEM_TYPE } from './Form';
var components = [BigTable, Cascader, DateRange, DetailInfo, DictSelect, DictText, FileUpload, Form, Image, Input, Loading, MixedInput, Modal, MultipleSelect, OssImage, PageHeader, SearchBar, SearchTable, Select, SuggestSelect, Table, TableOptions, TextArea, AbstractStep, BaseStepPage]; // 统一use的方法

var install = function install(Vue, options) {
  components.forEach(function (component) {
    Vue.use(component, options);
  });
}; // 其他导出


export default {
  install: install
}; // 组件导出

export { BigTable, Cascader, DateRange, DetailInfo, DictSelect, DictText, FileUpload, Form, Image, Input, Loading, MixedInput, Modal, MultipleSelect, OssImage, PageHeader, SearchBar, SearchTable, Select, SuggestSelect, Table, TableOptions, TextArea, AbstractStep, BaseStepPage, FORM_ITEM_TYPE };

==> better-admin-ui-vue-0.0.5.tgz: package/es/components/index.js <==
import BigTable from './BigTable';
import Cascader from './Cascader';
import DateRange from './DateRange';
import DetailInfo from './DetailInfo';
import DictSelect from './DictSelect';
import DictText from './DictText';
import FileUpload from './FileUpload';
import Form from './Form';
import Image from './Image';
import Input from './Input';
import Loading from './Loading';
import MixedInput from './MixedInput';
import Modal from './Modal';
import MultipleSelect from './MultipleSelect';
import OssImage from './OssImage';
import PageHeader from './PageHeader';
import SearchBar from './SearchBar';
import SearchTable from './SearchTable';
import Select from './Select';
import SuggestSelect from './SuggestSelect';
import Table from './Table';
import TableOptions from './TableOptions';
import TextArea from './TextArea';
import { AbstractStep, BaseStepPage } from './Step';
import { SearchTableMixin } from './SearchTable';
import { EASY_DETAIL_TYPE } from './DetailInfo';
import { FormMixin, FORM_ITEM_TYPE } from './Form';
var components = [BigTable, Cascader, DateRange, DetailInfo, DictSelect, DictText, FileUpload, Form, Image, Input, Loading, MixedInput, Modal, MultipleSelect, OssImage, PageHeader, SearchBar, SearchTable, Select, SuggestSelect, Table, TableOptions, TextArea, AbstractStep, BaseStepPage]; // 统一use的方法

var install = function install(Vue, options) {
  components.forEach(function (component) {
    Vue.use(component, options);
  });
}; // 其他导出


export default {
  install: install
}; // 组件导出

export { BigTable, Cascader, DateRange, DetailInfo, DictSelect, DictText, FileUpload, Form, Image, Input, Loading, MixedInput, Modal, MultipleSelect, OssImage, PageHeader, SearchBar, SearchTable, Select, SuggestSelect, Table, TableOptions, TextArea, AbstractStep, BaseStepPage, SearchTableMixin, EASY_DETAIL_TYPE, FormMixin, FORM_ITEM_TYPE };
